#
# Configuration file for using the XML library in GNOME applications
#
XML2_LIBDIR="-L/Users/ktietz/Code/oss/ci_pkgs/libxml2_1624461827303/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib"
XML2_LIBS="-lxml2 -L/Users/ktietz/Code/oss/ci_pkgs/libxml2_1624461827303/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib -lz -L/Users/ktietz/Code/oss/ci_pkgs/libxml2_1624461827303/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib -llzma -lpthread -L/Users/ktietz/Code/oss/ci_pkgs/libxml2_1624461827303/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib -liconv -L/Users/ktietz/Code/oss/ci_pkgs/libxml2_1624461827303/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib -licui18n -licuuc -licudata -lm "
XML2_INCLUDEDIR="-I/Users/ktietz/Code/oss/ci_pkgs/libxml2_1624461827303/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/include/libxml2 -I/Users/ktietz/Code/oss/ci_pkgs/libxml2_1624461827303/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/include"
MODULE_VERSION="xml2-2.9.10"

